#Region ;**** Directives created by AutoIt3Wrapper_GUI ****
#AutoIt3Wrapper_Icon=img\icon.ico
#AutoIt3Wrapper_Outfile=..\Release\MoveIt.exe
#AutoIt3Wrapper_Res_Description=Verschiebt Dateien von einem zum anderen Ordner
#AutoIt3Wrapper_Res_Fileversion=1.0.0.8
#AutoIt3Wrapper_Res_Fileversion_AutoIncrement=y
#AutoIt3Wrapper_Res_CompanyName=Freiwillige Feuerwehr Puschendorf
#AutoIt3Wrapper_Res_LegalCopyright= 2021 John Peter Kaplan
#AutoIt3Wrapper_Res_Language=1031
#EndRegion ;**** Directives created by AutoIt3Wrapper_GUI ****
#cs ----------------------------------------------------------------------------

 AutoIt Version: 3.3.14.5
 Author:         Kaplan, John Peter

 Script Function:
	Verschiebt definierte Dateien aus einem Ordner in einen Anderen

#ce ----------------------------------------------------------------------------

; Script Start
#include <Misc.au3>
#include <Array.au3>
#include <File.au3>
#include <FileConstants.au3>

Opt("TrayMenuMode", 1)

Local $strIniFile = @ScriptDir & "\" & StringTrimRight(@ScriptName, 3) & "ini"
Local $strLogFilePath = @ScriptDir & "\Logs"
Local $arySettings, $aryFileList
Local $strErrorMsg

; Verhindert, dass das Programm mehrmals gestartet werden kann
If _Singleton("MoveIt_KA2022", 1) == 0 Then
	MsgBox(262160, "Fehler", "Es wird schon eine Instanz von " & @ScriptName & " ausgefhrt. Der Programmstart wurde verhindert.")
	_WriteToLogfile("[E][-1][Es wird schon eine Instanz von " & @ScriptName & " ausgefhrt. Der Programmstart wurde verhindert.]")
	Exit
EndIf

While 1
	If Not FileExists($strIniFile) Then _CreateIniFile($strIniFile)
	$arySettings = IniReadSection($strIniFile, "Einstellungen")

	Sleep($arySettings[4][1] * 1000)

	$aryFileList = _FileListToArray($arySettings[1][1], "*" & $arySettings[3][1], $FLTA_FILES, False)
	If @error Then
		Switch @error
			Case 1
				$strErrorMsg = "[E][1][Ordner nicht gefunden oder ungltig]"
			Case 2
				$strErrorMsg = "[E][2][Ungltiger Filter: " & $arySettings[3][1] & "]"
			Case 4
				ContinueLoop
				$strErrorMsg = "[L][1][Keine Datei(en) gefunden]"
			Case Else
				$strErrorMsg = "[E][99][Unbekannter Fehler]"
		EndSwitch
		_WriteToLogfile($strErrorMsg)
		ContinueLoop
	EndIf

	For $i = 1 To $aryFileList[0]
		FileMove($arySettings[1][1] & "\" & $aryFileList[$i], $arySettings[2][1] & "\" & $aryFileList[$i], $FC_OVERWRITE + $FC_CREATEPATH)
		_WriteToLogfile("[L][2][Datei: """ & $aryFileList[$i] & """ wurde von: """ & $arySettings[1][1]& """ nach: """ & $arySettings[2][1]& """ verschoben]")
	Next
WEnd


;===============================================================================
; Function Name:   _WriteToLogfile($strErrorMsg, [$strLogFilePath])
; Description::    Schreibt eine Zeile in das Logfile
; Return Value(s): keine
; Author(s):       Kaplan, John Peter
;===============================================================================
Func _WriteToLogfile($strErrorMsg, $strLogFilePath = @ScriptDir & "\Logs")
	Local $hLogFile

	$hLogFile = FileOpen($strLogFilePath & "\" & "MoveIt_" & @YEAR & @MON & ".log", $FO_APPEND + $FO_CREATEPATH)
	_FileWriteLog($hLogFile, $strErrorMsg)
	FileClose($hLogFile)
EndFunc   ;==>_WriteToLogfile


;===============================================================================
; Function Name:   _CreateIniFile($strIniFile)
; Description::    Fragt die Initialisierungsparameter beim ersten Starte oder
;   			   fehlender Konfigurationsdatei ab und schreibt diese.
; Return Value(s): keine
; Author(s):       Kaplan, John Peter
;===============================================================================
Func _CreateIniFile($strIniFile)
	Local $strIniText
	Local $strSourceFolder, $strDestinationFolder, $strInputIntervall, $strInputType

	;MsgBox features: Title=Yes, Text=Yes, Buttons=OK, Icon=Info, Miscellaneous=Top-most attribute
	MsgBox(262208, "Konfigurationsdatei wurde nicht gefunden", "Es wurde keine Konfigurationsdatei gefunden. Es werden jetzt die einzelnen Parameter abgefragt und die Datei im Anschluss erzeugt." & @CRLF & @CRLF & _
			"Die Werte knnen in der Datei: " & $strIniFile & " spter von Hand gendert werden.")
	Do
		$strSourceFolder = FileSelectFolder("Whle den Quellordner aus", @ScriptDir)
		If @error Then Exit

		$strDestinationFolder = FileSelectFolder("Whle den Zielordner aus", @ScriptDir)
		If @error Then Exit

		If $strSourceFolder == $strDestinationFolder Then
			;MsgBox features: Title=Yes, Text=Yes, Buttons=OK, Icon=Critical, Miscellaneous=Top-most attribute
			MsgBox(262160, "Fehler", "Die Quelle und das Ziel drfen nicht gleich sein. Bitte whle unterschiedliche Verzeichnisse aus.")
		EndIf
	Until $strSourceFolder <> $strDestinationFolder

	$strInputIntervall = InputBox("Wiederholungsintervall", "Bitte gib das Wiederholungsintervall, in dem nach neuen Dateien gesucht werden soll, in Sekunden ein.", "5")
	If @error Then Exit

	$strInputType = InputBox("Dateityp", "Welcher Dateityp soll verschoben werden?" & @CRLF & @CRLF & "fr alle Dateien whle bitte: ""*""", "pdf")
	If @error Then Exit

	$strIniText = "[Einstellungen]" & @CRLF
	$strIniText &= "Quelle=" & $strSourceFolder & @CRLF
	$strIniText &= "Ziel=" & $strDestinationFolder & @CRLF
	$strIniText &= "Typ=" & $strInputType & @CRLF
	$strIniText &= "Intervall=" & $strInputIntervall

	FileWrite($strIniFile, $strIniText)
EndFunc   ;==>_CreateIniFile
